# Environment variables
set -gx BAT_STYLE plain
set -gx EDITOR nvim
set -gx LANG en_US.UTF-8
set -gx PAGER 'less --tabs=4 --jump-target=.25 -iRFM'
set -gx SBT_OPTS '-Dsbt.supershell=false'

if test -x /usr/libexec/java_home
    set -gx JAVA_HOME (/usr/libexec/java_home -v 1.8)
end

if command -q diff-so-fancy
    set -gx GIT_PAGER "diff-so-fancy | $PAGER"
end

if command -q interactive-rebase-tool
    set -gx GIT_SEQUENCE_EDITOR 'interactive-rebase-tool'
end

if status --is-interactive
    # Disable the default shell greeting
    set fish_greeting

    # Disable the abbreviated directory format
    set fish_prompt_pwd_dir_length 0

    # Abbreviations
    abbr -a -g d 'docker'
    abbr -a -g e $EDITOR
    abbr -a -g l 'less'
    abbr -a -g m 'micro'

    # Git abbreviations
    abbr -a -g g 'git'
    abbr -a -g ga 'git add'
    abbr -a -g gb 'git branchsort'
    abbr -a -g gbd 'git branch -D'
    abbr -a -g gc 'git commit'
    abbr -a -g gco 'git checkout'
    abbr -a -g gcp 'git cherry-pick'
    abbr -a -g gd 'git diff'
    abbr -a -g gdc 'git diff --cached'
    abbr -a -g gdh 'git diff --cached HEAD~'
    abbr -a -g gf 'git fetch --prune'
    abbr -a -g gl 'git log --oneline -10'
    abbr -a -g gr 'git restore'
    abbr -a -g gs 'git status'
    abbr -a -g gst 'git stash'
    abbr -a -g gsw 'git switch'

    # Git prompt
    set -g __fish_git_prompt_showdirtystate 1
    set -g __fish_git_prompt_showstashstate 1
    set -g __fish_git_prompt_showuntrackedfiles 1
    set -g __fish_git_prompt_showupstream informative
    set -g __fish_git_prompt_char_upstream_ahead '↑'
    set -g __fish_git_prompt_char_upstream_behind '↓'
    set -g __fish_git_prompt_char_upstream_prefix ' '
    set -g __fish_git_prompt_color_branch magenta
    set -g __fish_git_prompt_color_dirtystate cyan
    set -g __fish_git_prompt_color_invalidstate red
    set -g __fish_git_prompt_color_stagedstate cyan
    set -g __fish_git_prompt_color_stashstate cyan
    set -g __fish_git_prompt_color_untrackedfiles cyan
    set -g __fish_git_prompt_color_upstream yellow
end

if not set -q __universals_initialized
    set -U __universals_initialized

    # Colors
    set -U fish_color_autosuggestion a5a5a9
    set -U fish_color_cancel -r
    set -U fish_color_command green
    set -U fish_color_comment a5a5a9
    set -U fish_color_cwd green
    set -U fish_color_cwd_root red
    set -U fish_color_end brblack
    set -U fish_color_error red
    set -U fish_color_escape yellow
    set -U fish_color_history_current --bold
    set -U fish_color_host normal
    set -U fish_color_host_remote yellow
    set -U fish_color_match --background=brblue
    set -U fish_color_normal normal
    set -U fish_color_operator blue
    set -U fish_color_param white
    set -U fish_color_quote yellow
    set -U fish_color_redirection cyan
    set -U fish_color_search_match bryellow --background=515151
    set -U fish_color_selection white --bold --background=515151
    set -U fish_color_status red
    set -U fish_color_user brgreen
    set -U fish_color_valid_path --underline
    set -U fish_pager_color_completion normal
    set -U fish_pager_color_description yellow --dim
    set -U fish_pager_color_prefix white --bold
    set -U fish_pager_color_progress black --background=cyan
end
